var searchData=
[
  ['data_123',['DATA',['../a00572.html',1,'']]],
  ['data_2ec_124',['data.c',['../a00245.html',1,'']]],
  ['data_5flen_125',['data_len',['../a01212.html#aa9a66245e3c629a07111067cd1fdd0d4',1,'tds_packet']]],
  ['database_126',['database',['../a01192.html#ad05b5a83816aee8ff9858ddb1eb172b8',1,'tds_env']]],
  ['date_127',['date',['../a01108.html#a4697c11cf7da815856eb96bae4d57bac',1,'TDS_DATETIMEALL::date()'],['../a01316.html#afa93266cde7ab536615bca3d904aabed',1,'DBDATETIMEALL::date()']]],
  ['day_128',['day',['../a01112.html#a82d0cf263d8d4a3abcf84b9a146ddf83',1,'tdsdaterec']]],
  ['dayofyear_129',['dayofyear',['../a01112.html#a3f7925156708744d28016aacb90b6093',1,'tdsdaterec']]],
  ['db_5ffilename_130',['db_filename',['../a01132.html#a425f8ddd194f897f185d9f4d5e0618c2',1,'tds_login']]],
  ['dbacolname_131',['dbacolname',['../a00545.html#ga466690ceda8682382223d98a6ffb63bd',1,'dbacolname(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00545.html#ga466690ceda8682382223d98a6ffb63bd',1,'dbacolname(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbadata_132',['dbadata',['../a00545.html#gabcc14a1ca58b65bc46cce6c81c45218c',1,'dbadata(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00545.html#gabcc14a1ca58b65bc46cce6c81c45218c',1,'dbadata(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbadlen_133',['dbadlen',['../a00545.html#ga3340e21db274b272ec11c037cb147222',1,'dbadlen(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00545.html#ga3340e21db274b272ec11c037cb147222',1,'dbadlen(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbaltbind_134',['dbaltbind',['../a00545.html#gafefd17e15b22adda84366c817178dd7d',1,'dbaltbind(DBPROCESS *dbproc, int computeid, int column, int vartype, DBINT varlen, BYTE *varaddr):&#160;dblib.c'],['../a00545.html#gafefd17e15b22adda84366c817178dd7d',1,'dbaltbind(DBPROCESS *dbprocess, int computeid, int column, int vartype, DBINT varlen, BYTE *varaddr):&#160;dblib.c']]],
  ['dbaltcolid_135',['dbaltcolid',['../a00545.html#gad10c9fd75a86c7a0ac375937df0e90a6',1,'dbaltcolid(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00545.html#gad10c9fd75a86c7a0ac375937df0e90a6',1,'dbaltcolid(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbaltlen_136',['dbaltlen',['../a00545.html#ga9a35c8d3cd0e35c10555baf8f6a01e93',1,'dbaltlen(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00545.html#ga9a35c8d3cd0e35c10555baf8f6a01e93',1,'dbaltlen(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbaltop_137',['dbaltop',['../a00545.html#ga947837a5c8fd99898c043435945b668c',1,'dbaltop(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00545.html#ga947837a5c8fd99898c043435945b668c',1,'dbaltop(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbalttype_138',['dbalttype',['../a00545.html#gaa85171e020dc606f2bd3395ad1d3ab4f',1,'dbalttype(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00545.html#gaa85171e020dc606f2bd3395ad1d3ab4f',1,'dbalttype(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbaltutype_139',['dbaltutype',['../a00545.html#gaf1c00d83dfa88dc99a3fb449c49660ea',1,'dbaltutype(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c'],['../a00545.html#gaf1c00d83dfa88dc99a3fb449c49660ea',1,'dbaltutype(DBPROCESS *dbproc, int computeid, int column):&#160;dblib.c']]],
  ['dbanullbind_140',['dbanullbind',['../a00545.html#ga939c2a2e67b9992c787e2cec5b6cc1a7',1,'dbanullbind(DBPROCESS *dbproc, int computeid, int column, DBINT *indicator):&#160;dblib.c'],['../a00545.html#ga939c2a2e67b9992c787e2cec5b6cc1a7',1,'dbanullbind(DBPROCESS *dbprocess, int computeid, int column, DBINT *indicator):&#160;dblib.c']]],
  ['dbanydatecrack_141',['dbanydatecrack',['../a00545.html#gad57aa777300cf7f62077478ec6000d00',1,'dbanydatecrack(DBPROCESS *dbproc, DBDATEREC2 *di, int type, const void *data):&#160;dblib.c'],['../a00545.html#gad57aa777300cf7f62077478ec6000d00',1,'dbanydatecrack(DBPROCESS *dbproc, DBDATEREC2 *di, int type, const void *data):&#160;dblib.c']]],
  ['dbbind_142',['dbbind',['../a00545.html#ga873bc0f4663165e711655ade1dfae795',1,'dbbind(DBPROCESS *dbproc, int column, int vartype, DBINT varlen, BYTE *varaddr):&#160;dblib.c'],['../a00545.html#ga873bc0f4663165e711655ade1dfae795',1,'dbbind(DBPROCESS *dbproc, int column, int vartype, DBINT varlen, BYTE *varaddr):&#160;dblib.c']]],
  ['dbbylist_143',['dbbylist',['../a00545.html#gae658a0cd5270f3bd6f22de17b2cb2e64',1,'dbbylist(DBPROCESS *dbproc, int computeid, int *size):&#160;dblib.c'],['../a00545.html#gae658a0cd5270f3bd6f22de17b2cb2e64',1,'dbbylist(DBPROCESS *dbproc, int computeid, int *size):&#160;dblib.c']]],
  ['dbcancel_144',['dbcancel',['../a00545.html#ga5ea23272124fff03b8d87538c1ec3ee5',1,'dbcancel(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga5ea23272124fff03b8d87538c1ec3ee5',1,'dbcancel(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbcanquery_145',['dbcanquery',['../a00545.html#ga559e24ba70d0d96c3469eb6ab8f74e05',1,'dbcanquery(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga559e24ba70d0d96c3469eb6ab8f74e05',1,'dbcanquery(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbchange_146',['dbchange',['../a00545.html#ga8cbc761b1266bd947783d843aeeec264',1,'dbchange(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga8cbc761b1266bd947783d843aeeec264',1,'dbchange(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbclose_147',['dbclose',['../a00545.html#gaef740b394b44eb33925c2718f7b30d69',1,'dbclose(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gaef740b394b44eb33925c2718f7b30d69',1,'dbclose(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbclrbuf_148',['dbclrbuf',['../a00545.html#ga01404b179a251c249aecfdae72ec6ca4',1,'dbclrbuf(DBPROCESS *dbproc, DBINT n):&#160;dblib.c'],['../a00545.html#ga01404b179a251c249aecfdae72ec6ca4',1,'dbclrbuf(DBPROCESS *dbproc, DBINT n):&#160;dblib.c']]],
  ['dbclropt_149',['dbclropt',['../a00545.html#ga93ee3c8ca34a08588f88784898fd69e0',1,'dbclropt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c'],['../a00545.html#ga93ee3c8ca34a08588f88784898fd69e0',1,'dbclropt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c']]],
  ['dbcmd_150',['dbcmd',['../a00545.html#ga87b39d9863316b4ba85654b0885d53a0',1,'dbcmd(DBPROCESS *dbproc, const char cmdstring[]):&#160;dblib.c'],['../a00545.html#ga87b39d9863316b4ba85654b0885d53a0',1,'dbcmd(DBPROCESS *dbproc, const char cmdstring[]):&#160;dblib.c']]],
  ['dbcmdrow_151',['DBCMDROW',['../a00545.html#ga8b263669ce0312e52b5ea42a57a56838',1,'DBCMDROW():&#160;sybdb.h'],['../a00551.html#ga196f6d67de47f34a32fcc2103ab0f416',1,'dbcmdrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga196f6d67de47f34a32fcc2103ab0f416',1,'dbcmdrow(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbcol_152',['DBCOL',['../a01328.html',1,'']]],
  ['dbcol2_153',['DBCOL2',['../a01332.html',1,'']]],
  ['dbcolinfo_154',['dbcolinfo',['../a00080.html#a9b73fd1afa2c3ccfca481635212d2e43',1,'dbcolinfo(DBPROCESS *dbproc, CI_TYPE type, DBINT column, DBINT computeid, DBCOL *pdbcol):&#160;dblib.c'],['../a00503.html#a9b73fd1afa2c3ccfca481635212d2e43',1,'dbcolinfo(DBPROCESS *dbproc, CI_TYPE type, DBINT column, DBINT computeid, DBCOL *pdbcol):&#160;dblib.c']]],
  ['dbcollen_155',['dbcollen',['../a00545.html#ga89fc5589b4bf41932324d2cfc6ad6433',1,'dbcollen(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#ga89fc5589b4bf41932324d2cfc6ad6433',1,'dbcollen(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbcolname_156',['dbcolname',['../a00545.html#gad06f5deddac18604dfa858b2580e232f',1,'dbcolname(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#gad06f5deddac18604dfa858b2580e232f',1,'dbcolname(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbcolptr_157',['dbcolptr',['../a00551.html#ga0fc84c7073ed4876d9596c3eccac3609',1,'dblib.c']]],
  ['dbcolsource_158',['dbcolsource',['../a00545.html#ga3a96d0188e5e0eb9eea661b3685fdcc3',1,'dbcolsource(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#ga3a96d0188e5e0eb9eea661b3685fdcc3',1,'dbcolsource(DBPROCESS *dbproc, int colnum):&#160;dblib.c']]],
  ['dbcoltype_159',['dbcoltype',['../a00545.html#ga636e6f1b64743f3cf22158a56eef371f',1,'dbcoltype(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#ga636e6f1b64743f3cf22158a56eef371f',1,'dbcoltype(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbcoltypeinfo_160',['dbcoltypeinfo',['../a00545.html#ga3c33e72c41b40e08dbcfdfa0d16bc399',1,'dbcoltypeinfo(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#ga3c33e72c41b40e08dbcfdfa0d16bc399',1,'dbcoltypeinfo(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbcolutype_161',['dbcolutype',['../a00545.html#gab33d2f4fd44f50e55b6c71902db4fdae',1,'dbcolutype(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#gab33d2f4fd44f50e55b6c71902db4fdae',1,'dbcolutype(DBPROCESS *dbprocess, int column):&#160;dblib.c']]],
  ['dbconvert_162',['dbconvert',['../a00545.html#ga32eb72f6fb3edb130e59fb3dd0766e7e',1,'dbconvert(DBPROCESS *dbproc, int srctype, const BYTE *src, DBINT srclen, int desttype, BYTE *dest, DBINT destlen):&#160;dblib.c'],['../a00545.html#ga32eb72f6fb3edb130e59fb3dd0766e7e',1,'dbconvert(DBPROCESS *dbproc, int srctype, const BYTE *src, DBINT srclen, int desttype, BYTE *dest, DBINT destlen):&#160;dblib.c']]],
  ['dbconvert_5fps_163',['dbconvert_ps',['../a00545.html#ga8b00d5cdcaa20cba13fa2e03d52a443e',1,'dbconvert_ps(DBPROCESS *dbproc, int db_srctype, const BYTE *src, DBINT srclen, int db_desttype, BYTE *dest, DBINT destlen, DBTYPEINFO *typeinfo):&#160;dblib.c'],['../a00545.html#ga8b00d5cdcaa20cba13fa2e03d52a443e',1,'dbconvert_ps(DBPROCESS *dbprocess, int srctype, const BYTE *src, DBINT srclen, int desttype, BYTE *dest, DBINT destlen, DBTYPEINFO *typeinfo):&#160;dblib.c']]],
  ['dbcount_164',['DBCOUNT',['../a00545.html#ga0ac1828f731a21c591c8d6330cbba3a9',1,'DBCOUNT():&#160;sybdb.h'],['../a00545.html#ga9433bc200c0978569964354451d9b64e',1,'dbcount(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga9433bc200c0978569964354451d9b64e',1,'dbcount(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbcurcmd_165',['dbcurcmd',['../a00551.html#ga01e7fb38bece3bb07526532fa6be50e5',1,'dbcurcmd(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga01e7fb38bece3bb07526532fa6be50e5',1,'dbcurcmd(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gae375344b1ec50c1f756e3b69f3cef715',1,'DBCURCMD():&#160;sybdb.h']]],
  ['dbcurrow_166',['dbcurrow',['../a00551.html#ga9e23a95d84192b4fc83db7544d772d16',1,'dbcurrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga9e23a95d84192b4fc83db7544d772d16',1,'dbcurrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gaf49e4b58918bfa4d4adaa14ee5bb375c',1,'DBCURROW():&#160;sybdb.h']]],
  ['dbdata_167',['dbdata',['../a00545.html#gaee60c306a22383805a4b9caa647a1e16',1,'dbdata(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#gaee60c306a22383805a4b9caa647a1e16',1,'dbdata(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbdatecmp_168',['dbdatecmp',['../a00550.html#ga129d2922d347121a6b312dd8e75ed6d2',1,'dbdatecmp(DBPROCESS *dbproc, DBDATETIME *d1, DBDATETIME *d2):&#160;dblib.c'],['../a00550.html#ga129d2922d347121a6b312dd8e75ed6d2',1,'dbdatecmp(DBPROCESS *dbproc, DBDATETIME *d1, DBDATETIME *d2):&#160;dblib.c']]],
  ['dbdatecrack_169',['dbdatecrack',['../a00545.html#ga46f3641b79a2e90371a66950b6db2c4d',1,'dbdatecrack(DBPROCESS *dbproc, DBDATEREC *di, DBDATETIME *datetime):&#160;dblib.c'],['../a00545.html#ga46f3641b79a2e90371a66950b6db2c4d',1,'dbdatecrack(DBPROCESS *dbproc, DBDATEREC *di, DBDATETIME *dt):&#160;dblib.c']]],
  ['dbdatetime_170',['DBDATETIME',['../a01308.html',1,'']]],
  ['dbdatetime4_171',['DBDATETIME4',['../a01312.html',1,'']]],
  ['dbdatetimeall_172',['DBDATETIMEALL',['../a01316.html',1,'']]],
  ['dbdatlen_173',['dbdatlen',['../a00545.html#gae666d141533126babb0235af21bdca0f',1,'dbdatlen(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#gae666d141533126babb0235af21bdca0f',1,'dbdatlen(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbdead_174',['dbdead',['../a00551.html#gaed43cb21ed54dc1a6340075d6290e4b0',1,'dbdead(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#gaed43cb21ed54dc1a6340075d6290e4b0',1,'dbdead(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga2c7b5eec4843ea326b21f2db2ded2754',1,'DBDEAD():&#160;sybdb.h']]],
  ['dberrhandle_175',['dberrhandle',['../a00545.html#gab8209543de865f359bdb32829fa8b757',1,'dberrhandle(EHANDLEFUNC handler):&#160;dblib.c'],['../a00545.html#gab8209543de865f359bdb32829fa8b757',1,'dberrhandle(EHANDLEFUNC handler):&#160;dblib.c']]],
  ['dbexit_176',['dbexit',['../a00545.html#gad0044401c8c83205583f93a4764f2d8b',1,'dbexit():&#160;dblib.c'],['../a00545.html#gad0044401c8c83205583f93a4764f2d8b',1,'dbexit(void):&#160;dblib.c']]],
  ['dbfcmd_177',['dbfcmd',['../a00545.html#ga43727b10d4cbb7708b374811abe6eadb',1,'dbfcmd(DBPROCESS *dbproc, const char *fmt,...):&#160;dblib.c'],['../a00545.html#ga43727b10d4cbb7708b374811abe6eadb',1,'dbfcmd(DBPROCESS *dbproc, const char *fmt,...):&#160;dblib.c']]],
  ['dbfirstrow_178',['DBFIRSTROW',['../a00545.html#ga97a6493786124215ec9fe4b4bd2d7cbb',1,'DBFIRSTROW():&#160;sybdb.h'],['../a00551.html#gaf40b925f3b3ba43804720dd4ae584935',1,'dbfirstrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#gaf40b925f3b3ba43804720dd4ae584935',1,'dbfirstrow(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbfreebuf_179',['dbfreebuf',['../a00545.html#ga0fcfcf6846442dac9dd5584d270ec72a',1,'dbfreebuf(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga0fcfcf6846442dac9dd5584d270ec72a',1,'dbfreebuf(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbgetchar_180',['dbgetchar',['../a00545.html#gaf917cf746c954a5d1b718afe3c4d1940',1,'dbgetchar(DBPROCESS *dbproc, int pos):&#160;dblib.c'],['../a00545.html#gaf917cf746c954a5d1b718afe3c4d1940',1,'dbgetchar(DBPROCESS *dbprocess, int n):&#160;dblib.c']]],
  ['dbgetmaxprocs_181',['dbgetmaxprocs',['../a00545.html#gadb34c5c2aae50ac9f2a26d8984136997',1,'dbgetmaxprocs(void):&#160;dblib.c'],['../a00545.html#gadb34c5c2aae50ac9f2a26d8984136997',1,'dbgetmaxprocs(void):&#160;dblib.c']]],
  ['dbgetnull_182',['dbgetnull',['../a00080.html#aea6a865806d454280126de940478c214',1,'dblib.c']]],
  ['dbgetpacket_183',['dbgetpacket',['../a00545.html#gabaf9aa756f7cb8bbec80d1c7201c6238',1,'dbgetpacket(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gabaf9aa756f7cb8bbec80d1c7201c6238',1,'dbgetpacket(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbgetrow_184',['dbgetrow',['../a00545.html#ga60fe544491c760f8bc6c37bc7f777d70',1,'dbgetrow(DBPROCESS *dbproc, DBINT row):&#160;dblib.c'],['../a00545.html#ga60fe544491c760f8bc6c37bc7f777d70',1,'dbgetrow(DBPROCESS *dbproc, DBINT row):&#160;dblib.c']]],
  ['dbgettime_185',['dbgettime',['../a00545.html#ga6ccffbb3f0cfb10883ad349f1e47c50e',1,'dbgettime(void):&#160;dblib.c'],['../a00545.html#ga6ccffbb3f0cfb10883ad349f1e47c50e',1,'dbgettime(void):&#160;dblib.c']]],
  ['dbgetuserdata_186',['dbgetuserdata',['../a00545.html#gaa5714a91d7c14365fa1e5b164bb2b0b6',1,'dbgetuserdata(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gaa5714a91d7c14365fa1e5b164bb2b0b6',1,'dbgetuserdata(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbhasretstat_187',['dbhasretstat',['../a00546.html#ga7a5062dac92ccedc8459f6d4a530ffb7',1,'dbhasretstat(DBPROCESS *dbproc):&#160;dblib.c'],['../a00546.html#ga7a5062dac92ccedc8459f6d4a530ffb7',1,'dbhasretstat(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbinit_188',['dbinit',['../a00545.html#ga564dd3a1bb0425a8957f1714d8b2a7c0',1,'dbinit(void):&#160;dblib.c'],['../a00545.html#ga564dd3a1bb0425a8957f1714d8b2a7c0',1,'dbinit(void):&#160;dblib.c']]],
  ['dbiordesc_189',['dbiordesc',['../a00551.html#gab842baac0ec420b265d8c199cc45059d',1,'dbiordesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#gab842baac0ec420b265d8c199cc45059d',1,'dbiordesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga74ac942f9b7baa49e1d7d18628321297',1,'DBIORDESC():&#160;sybdb.h']]],
  ['dbiowdesc_190',['dbiowdesc',['../a00551.html#ga666a4d0609ee7f241deb0a62893d2cfa',1,'dbiowdesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga666a4d0609ee7f241deb0a62893d2cfa',1,'dbiowdesc(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga5afb13924cda059d30be36a70dcf2cd9',1,'DBIOWDESC():&#160;sybdb.h']]],
  ['dbisavail_191',['DBISAVAIL',['../a00545.html#ga40f6c951a851744e58ee715c652a8ac8',1,'sybdb.h']]],
  ['dbiscount_192',['dbiscount',['../a00545.html#ga6ba2a7f18cb76d24776e45fd71141494',1,'dbiscount(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga6ba2a7f18cb76d24776e45fd71141494',1,'dbiscount(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbisopt_193',['dbisopt',['../a00545.html#gac3eb8cb53f50998403ea9aebc6263df9',1,'dbisopt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c'],['../a00545.html#gac3eb8cb53f50998403ea9aebc6263df9',1,'dbisopt(DBPROCESS *dbproc, int option, const char param[]):&#160;dblib.c']]],
  ['dblastrow_194',['DBLASTROW',['../a00545.html#ga10b9b26cf9a901146e9675a9e678632b',1,'DBLASTROW():&#160;sybdb.h'],['../a00551.html#ga13ead146339b43b3a4d9049eb124ef4b',1,'dblastrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga13ead146339b43b3a4d9049eb124ef4b',1,'dblastrow(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dblib_2ec_195',['dblib.c',['../a00080.html',1,'']]],
  ['dblib_5fbuffer_5frow_196',['dblib_buffer_row',['../a00608.html',1,'']]],
  ['dblib_5fcontext_197',['dblib_context',['../a00612.html',1,'']]],
  ['datetime_20functions_198',['Datetime functions',['../a00550.html',1,'']]],
  ['dblib_5ferror_5fmessage_199',['DBLIB_ERROR_MESSAGE',['../a00551.html#ga8f2b5c6bcfed3eb54e97b42a6f8930f8',1,'dblib.c']]],
  ['dblibcontext_200',['DBLIBCONTEXT',['../a00080.html#a8ff1bdcccb992dd688bc35d178c4bf3b',1,'dblib.c']]],
  ['dblogin_201',['dblogin',['../a00545.html#ga0984798bb806f7451a53bffa7e2c430f',1,'dblogin(void):&#160;dblib.c'],['../a00545.html#ga0984798bb806f7451a53bffa7e2c430f',1,'dblogin(void):&#160;dblib.c']]],
  ['dbloginfree_202',['dbloginfree',['../a00545.html#gac1bdb1766b791153f37dceae8ff64ad6',1,'dbloginfree(LOGINREC *login):&#160;dblib.c'],['../a00545.html#gac1bdb1766b791153f37dceae8ff64ad6',1,'dbloginfree(LOGINREC *login):&#160;dblib.c']]],
  ['dbmny4add_203',['dbmny4add',['../a00549.html#ga0a384938a6586b7411fc42420ffad6ed',1,'dbmny4add(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *sum):&#160;dblib.c'],['../a00549.html#ga0a384938a6586b7411fc42420ffad6ed',1,'dbmny4add(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *sum):&#160;dblib.c']]],
  ['dbmny4cmp_204',['dbmny4cmp',['../a00549.html#ga109d4868baccb08fad3b26b6f031dc78',1,'dbmny4cmp(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2):&#160;dblib.c'],['../a00549.html#ga109d4868baccb08fad3b26b6f031dc78',1,'dbmny4cmp(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2):&#160;dblib.c']]],
  ['dbmny4copy_205',['dbmny4copy',['../a00549.html#gaa6d4c700b628f6a18a9d1ed9f8e2ba62',1,'dbmny4copy(DBPROCESS *dbproc, DBMONEY4 *src, DBMONEY4 *dest):&#160;dblib.c'],['../a00549.html#gaa6d4c700b628f6a18a9d1ed9f8e2ba62',1,'dbmny4copy(DBPROCESS *dbprocess, DBMONEY4 *m1, DBMONEY4 *m2):&#160;dblib.c']]],
  ['dbmny4minus_206',['dbmny4minus',['../a00549.html#ga76177eb61a67dd52424236aba1b16bc9',1,'dbmny4minus(DBPROCESS *dbproc, DBMONEY4 *src, DBMONEY4 *dest):&#160;dblib.c'],['../a00549.html#ga76177eb61a67dd52424236aba1b16bc9',1,'dbmny4minus(DBPROCESS *dbproc, DBMONEY4 *src, DBMONEY4 *dest):&#160;dblib.c']]],
  ['dbmny4sub_207',['dbmny4sub',['../a00549.html#ga856143f4f9c7a5c15fb15633af81487d',1,'dbmny4sub(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *diff):&#160;dblib.c'],['../a00549.html#ga856143f4f9c7a5c15fb15633af81487d',1,'dbmny4sub(DBPROCESS *dbproc, DBMONEY4 *m1, DBMONEY4 *m2, DBMONEY4 *diff):&#160;dblib.c']]],
  ['dbmny4zero_208',['dbmny4zero',['../a00549.html#ga070e94f72f12c138a16a7bcdf732fa8b',1,'dbmny4zero(DBPROCESS *dbproc, DBMONEY4 *dest):&#160;dblib.c'],['../a00549.html#ga070e94f72f12c138a16a7bcdf732fa8b',1,'dbmny4zero(DBPROCESS *dbproc, DBMONEY4 *dest):&#160;dblib.c']]],
  ['dbmnycmp_209',['dbmnycmp',['../a00549.html#gadddacad5c3028aa8d3726246c3825651',1,'dbmnycmp(DBPROCESS *dbproc, DBMONEY *m1, DBMONEY *m2):&#160;dblib.c'],['../a00549.html#gadddacad5c3028aa8d3726246c3825651',1,'dbmnycmp(DBPROCESS *dbproc, DBMONEY *m1, DBMONEY *m2):&#160;dblib.c']]],
  ['dbmnycopy_210',['dbmnycopy',['../a00549.html#ga8f1e9aa0280c1cb46c10e5c90b8faced',1,'dbmnycopy(DBPROCESS *dbproc, DBMONEY *src, DBMONEY *dest):&#160;dblib.c'],['../a00549.html#ga8f1e9aa0280c1cb46c10e5c90b8faced',1,'dbmnycopy(DBPROCESS *dbproc, DBMONEY *src, DBMONEY *dest):&#160;dblib.c']]],
  ['dbmnydec_211',['dbmnydec',['../a00549.html#gabedce74748a31ea8a6e4068a5d44d8e4',1,'dbmnydec(DBPROCESS *dbproc, DBMONEY *amount):&#160;dblib.c'],['../a00549.html#gabedce74748a31ea8a6e4068a5d44d8e4',1,'dbmnydec(DBPROCESS *dbproc, DBMONEY *mnyptr):&#160;dblib.c']]],
  ['dbmnyinc_212',['dbmnyinc',['../a00549.html#gabf5216aaaa59ea7e7f07899f82a27faf',1,'dbmnyinc(DBPROCESS *dbproc, DBMONEY *amount):&#160;dblib.c'],['../a00549.html#gabf5216aaaa59ea7e7f07899f82a27faf',1,'dbmnyinc(DBPROCESS *dbproc, DBMONEY *mnyptr):&#160;dblib.c']]],
  ['dbmnymaxneg_213',['dbmnymaxneg',['../a00549.html#gabc3cb44d33bf1b9b18fd59f23e4da722',1,'dbmnymaxneg(DBPROCESS *dbproc, DBMONEY *amount):&#160;dblib.c'],['../a00549.html#gabc3cb44d33bf1b9b18fd59f23e4da722',1,'dbmnymaxneg(DBPROCESS *dbproc, DBMONEY *dest):&#160;dblib.c']]],
  ['dbmnymaxpos_214',['dbmnymaxpos',['../a00549.html#ga70ca2474f6c93acd6e3b842330b712c7',1,'dbmnymaxpos(DBPROCESS *dbproc, DBMONEY *amount):&#160;dblib.c'],['../a00549.html#ga70ca2474f6c93acd6e3b842330b712c7',1,'dbmnymaxpos(DBPROCESS *dbproc, DBMONEY *dest):&#160;dblib.c']]],
  ['dbmnyminus_215',['dbmnyminus',['../a00549.html#ga826bca98da4fd1c3188da45c383c3a68',1,'dbmnyminus(DBPROCESS *dbproc, DBMONEY *src, DBMONEY *dest):&#160;dblib.c'],['../a00549.html#ga826bca98da4fd1c3188da45c383c3a68',1,'dbmnyminus(DBPROCESS *dbproc, DBMONEY *src, DBMONEY *dest):&#160;dblib.c']]],
  ['dbmnyzero_216',['dbmnyzero',['../a00549.html#ga8eab0959d5a3cd534487b350258c939e',1,'dbmnyzero(DBPROCESS *dbproc, DBMONEY *dest):&#160;dblib.c'],['../a00549.html#ga8eab0959d5a3cd534487b350258c939e',1,'dbmnyzero(DBPROCESS *dbproc, DBMONEY *dest):&#160;dblib.c']]],
  ['dbmoney_217',['DBMONEY',['../a01300.html',1,'']]],
  ['dbmoney4_218',['DBMONEY4',['../a01304.html',1,'']]],
  ['dbmonthname_219',['dbmonthname',['../a00550.html#ga38ecd55ae5827bfa0fd12e2baf0950dd',1,'dbmonthname(DBPROCESS *dbproc, char *language, int monthnum, DBBOOL shortform):&#160;dblib.c'],['../a00550.html#ga38ecd55ae5827bfa0fd12e2baf0950dd',1,'dbmonthname(DBPROCESS *dbproc, char *language, int monthnum, DBBOOL shortform):&#160;dblib.c']]],
  ['dbmorecmds_220',['dbmorecmds',['../a00545.html#gac3ba9f53cc77e4dde8f48335ed94ac19',1,'dbmorecmds(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gac3ba9f53cc77e4dde8f48335ed94ac19',1,'dbmorecmds(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gad887bdce8cb0d3b8c6aaf659eb477b48',1,'DBMORECMDS():&#160;sybdb.h']]],
  ['dbmoretext_221',['dbmoretext',['../a00545.html#ga6f13381522a1fa0b6ce2c15378088cdd',1,'dbmoretext(DBPROCESS *dbproc, DBINT size, const BYTE text[]):&#160;dblib.c'],['../a00545.html#ga6f13381522a1fa0b6ce2c15378088cdd',1,'dbmoretext(DBPROCESS *dbproc, DBINT size, const BYTE text[]):&#160;dblib.c']]],
  ['dbmsghandle_222',['dbmsghandle',['../a00545.html#gadc8af9a65f3719804c2537fd737298ca',1,'dbmsghandle(MHANDLEFUNC handler):&#160;dblib.c'],['../a00545.html#gadc8af9a65f3719804c2537fd737298ca',1,'dbmsghandle(MHANDLEFUNC handler):&#160;dblib.c']]],
  ['dbname_223',['dbname',['../a00545.html#gab185982ffe0b85b8fd19747bd1f433fe',1,'dbname(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gab185982ffe0b85b8fd19747bd1f433fe',1,'dbname(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbnullbind_224',['dbnullbind',['../a00545.html#ga85dcc40c3615f94be96b09b2ec043533',1,'dbnullbind(DBPROCESS *dbproc, int column, DBINT *indicator):&#160;dblib.c'],['../a00545.html#ga85dcc40c3615f94be96b09b2ec043533',1,'dbnullbind(DBPROCESS *dbproc, int column, DBINT *indicator):&#160;dblib.c']]],
  ['dbnumalts_225',['dbnumalts',['../a00545.html#ga67934deac3bebbf8238eff8c0559389a',1,'dbnumalts(DBPROCESS *dbproc, int computeid):&#160;dblib.c'],['../a00545.html#ga67934deac3bebbf8238eff8c0559389a',1,'dbnumalts(DBPROCESS *dbproc, int computeid):&#160;dblib.c']]],
  ['dbnumcols_226',['dbnumcols',['../a00545.html#gadaa9482a082aa3fe52231e17749c2993',1,'dbnumcols(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gadaa9482a082aa3fe52231e17749c2993',1,'dbnumcols(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbnumcompute_227',['dbnumcompute',['../a00545.html#gac554d2cb2da0c9f9fd3d4867998edcc4',1,'dbnumcompute(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gac554d2cb2da0c9f9fd3d4867998edcc4',1,'dbnumcompute(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbnumeric_228',['DBNUMERIC',['../a01296.html',1,'']]],
  ['dbnumrets_229',['dbnumrets',['../a00546.html#gaff09873008411a0573f6d1a9e6c7cf4b',1,'dbnumrets(DBPROCESS *dbproc):&#160;dblib.c'],['../a00546.html#gaff09873008411a0573f6d1a9e6c7cf4b',1,'dbnumrets(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbopen_230',['dbopen',['../a00503.html#ae408d8e1c2ab0767d8bfd26d00d1ff6a',1,'dbopen.c']]],
  ['dboption_231',['dboption',['../a00932.html',1,'']]],
  ['dbperror_232',['dbperror',['../a00551.html#ga302a4ce6559b81808e3be51615cd1b67',1,'dbperror(DBPROCESS *dbproc, DBINT msgno, long errnum,...):&#160;dblib.c'],['../a00551.html#ga302a4ce6559b81808e3be51615cd1b67',1,'dbperror(DBPROCESS *dbproc, DBINT msgno, long errnum,...):&#160;dblib.c']]],
  ['dbpivot_233',['dbpivot',['../a00503.html#af8ada101cd189eff87b3533cbeaaa23b',1,'dbpivot.c']]],
  ['dbprcollen_234',['dbprcollen',['../a00545.html#gac0cb0584f6500d61a2ac95a891da73eb',1,'dbprcollen(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#gac0cb0584f6500d61a2ac95a891da73eb',1,'dbprcollen(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbprhead_235',['dbprhead',['../a00545.html#ga9dfc2ee533e5e48a7aa8ca22f8d9ed79',1,'dbprhead(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga9dfc2ee533e5e48a7aa8ca22f8d9ed79',1,'dbprhead(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbproc_5frowbuf_236',['DBPROC_ROWBUF',['../a00912.html',1,'']]],
  ['dbprrow_237',['dbprrow',['../a00545.html#gaa30be3414a97aac6139af2e928db91ca',1,'dbprrow(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gaa30be3414a97aac6139af2e928db91ca',1,'dbprrow(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbprtype_238',['dbprtype',['../a00545.html#gac25ae21ca19777ffab1c013bd6049ebf',1,'dbprtype(int token):&#160;dblib.c'],['../a00545.html#gac25ae21ca19777ffab1c013bd6049ebf',1,'dbprtype(int token):&#160;dblib.c']]],
  ['dbreadtext_239',['dbreadtext',['../a00545.html#gadd5685565c8c6c86079e17b8a73b324c',1,'dbreadtext(DBPROCESS *dbproc, void *buf, DBINT bufsize):&#160;dblib.c'],['../a00545.html#gadd5685565c8c6c86079e17b8a73b324c',1,'dbreadtext(DBPROCESS *dbproc, void *buf, DBINT bufsize):&#160;dblib.c']]],
  ['dbrecftos_240',['dbrecftos',['../a00545.html#gabb14ad9f268b92a8d63fa506098b24dd',1,'dbrecftos(const char filename[]):&#160;dblib.c'],['../a00545.html#gabb14ad9f268b92a8d63fa506098b24dd',1,'dbrecftos(const char filename[]):&#160;dblib.c']]],
  ['dbremote_5fproc_241',['DBREMOTE_PROC',['../a00928.html',1,'']]],
  ['dbremote_5fproc_5fparam_242',['DBREMOTE_PROC_PARAM',['../a00924.html',1,'']]],
  ['dbresults_243',['dbresults',['../a00545.html#ga4e26d949be2c3bf71b1a33c75b11d931',1,'dbresults(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga4e26d949be2c3bf71b1a33c75b11d931',1,'dbresults(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbretdata_244',['dbretdata',['../a00546.html#ga42e187003b74fec6e9ca92d410bfb9c0',1,'dbretdata(DBPROCESS *dbproc, int retnum):&#160;dblib.c'],['../a00546.html#ga42e187003b74fec6e9ca92d410bfb9c0',1,'dbretdata(DBPROCESS *dbproc, int retnum):&#160;dblib.c']]],
  ['dbretlen_245',['dbretlen',['../a00546.html#gab705bf94be535e9d8fc4edc0f48c98b0',1,'dbretlen(DBPROCESS *dbproc, int retnum):&#160;dblib.c'],['../a00546.html#gab705bf94be535e9d8fc4edc0f48c98b0',1,'dbretlen(DBPROCESS *dbproc, int retnum):&#160;dblib.c']]],
  ['dbretname_246',['dbretname',['../a00546.html#ga0311328d63bae5d9bd5aea5ea4914223',1,'dbretname(DBPROCESS *dbproc, int retnum):&#160;dblib.c'],['../a00546.html#ga0311328d63bae5d9bd5aea5ea4914223',1,'dbretname(DBPROCESS *dbproc, int retnum):&#160;dblib.c']]],
  ['dbretstatus_247',['dbretstatus',['../a00546.html#ga2306039d73fbc7045f257b0e750c37b4',1,'dbretstatus(DBPROCESS *dbproc):&#160;dblib.c'],['../a00546.html#ga2306039d73fbc7045f257b0e750c37b4',1,'dbretstatus(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbrettype_248',['dbrettype',['../a00546.html#gaa478c8b96923bca02d158d966172ec1b',1,'dbrettype(DBPROCESS *dbproc, int retnum):&#160;dblib.c'],['../a00546.html#gaa478c8b96923bca02d158d966172ec1b',1,'dbrettype(DBPROCESS *dbproc, int retnum):&#160;dblib.c']]],
  ['dbrows_249',['DBROWS',['../a00545.html#ga48d71b32c26703c810191ef916c5448c',1,'DBROWS():&#160;sybdb.h'],['../a00551.html#ga4be2ab59dc7161d6b93c17202e7ae9b1',1,'dbrows(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga4be2ab59dc7161d6b93c17202e7ae9b1',1,'dbrows(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbrowtype_250',['DBROWTYPE',['../a00545.html#ga6fda3f4982dda5825d13fee392e89fd9',1,'DBROWTYPE():&#160;sybdb.h'],['../a00551.html#gaa2dc8c062342f76adffe53ee280b7fb4',1,'dbrowtype(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#gaa2dc8c062342f76adffe53ee280b7fb4',1,'dbrowtype(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbrpcinit_251',['dbrpcinit',['../a00546.html#ga5b4374c13c7a83cd4345b0bfa3e787bd',1,'dbrpcinit(DBPROCESS *dbproc, const char rpcname[], DBSMALLINT options):&#160;rpc.c'],['../a00546.html#ga5b4374c13c7a83cd4345b0bfa3e787bd',1,'dbrpcinit(DBPROCESS *dbproc, const char rpcname[], DBSMALLINT options):&#160;rpc.c']]],
  ['dbrpcparam_252',['dbrpcparam',['../a00546.html#gaf6b6b0a641180a5c28382df39cd7d346',1,'dbrpcparam(DBPROCESS *dbproc, const char paramname[], BYTE status, int db_type, DBINT maxlen, DBINT datalen, BYTE *value):&#160;rpc.c'],['../a00546.html#gaf6b6b0a641180a5c28382df39cd7d346',1,'dbrpcparam(DBPROCESS *dbproc, const char paramname[], BYTE status, int type, DBINT maxlen, DBINT datalen, BYTE *value):&#160;rpc.c']]],
  ['dbrpcsend_253',['dbrpcsend',['../a00546.html#gafa4dfd181be21e49c397f7daaa9cf96c',1,'dbrpcsend(DBPROCESS *dbproc):&#160;rpc.c'],['../a00546.html#gafa4dfd181be21e49c397f7daaa9cf96c',1,'dbrpcsend(DBPROCESS *dbproc):&#160;rpc.c']]],
  ['dbsafestr_254',['dbsafestr',['../a00545.html#gad0ccc03b94ba2515fd1f5d35559fcb41',1,'dbsafestr(DBPROCESS *dbproc, const char *src, DBINT srclen, char *dest, DBINT destlen, int quotetype):&#160;dblib.c'],['../a00545.html#gad0ccc03b94ba2515fd1f5d35559fcb41',1,'dbsafestr(DBPROCESS *dbproc, const char *src, DBINT srclen, char *dest, DBINT destlen, int quotetype):&#160;dblib.c']]],
  ['dbservcharset_255',['dbservcharset',['../a00545.html#ga39302e8efbb476ba01cff109ffb3661e',1,'dbservcharset(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga39302e8efbb476ba01cff109ffb3661e',1,'dbservcharset(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbsetavail_256',['dbsetavail',['../a00551.html#ga5ce245ff327a3d333280fe7b43d69ded',1,'dbsetavail(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga5ce245ff327a3d333280fe7b43d69ded',1,'dbsetavail(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbsetifile_257',['dbsetifile',['../a00545.html#ga663350909fec3a1d152316c45a65e708',1,'dbsetifile(char *filename):&#160;dblib.c'],['../a00545.html#ga663350909fec3a1d152316c45a65e708',1,'dbsetifile(char *filename):&#160;dblib.c']]],
  ['dbsetinterrupt_258',['dbsetinterrupt',['../a00545.html#ga335fcbe476ad0f897e4e2ce377f0a8cc',1,'dbsetinterrupt(DBPROCESS *dbproc, DB_DBCHKINTR_FUNC chkintr, DB_DBHNDLINTR_FUNC hndlintr):&#160;dblib.c'],['../a00545.html#ga335fcbe476ad0f897e4e2ce377f0a8cc',1,'dbsetinterrupt(DBPROCESS *dbproc, DB_DBCHKINTR_FUNC chkintr, DB_DBHNDLINTR_FUNC hndlintr):&#160;dblib.c']]],
  ['dbsetlapp_259',['DBSETLAPP',['../a00544.html#gab6c2da7fd615cf7462d555e5387a5580',1,'sybdb.h']]],
  ['dbsetlbool_260',['dbsetlbool',['../a00551.html#ga03e850369aca6fba074da5e9da4effd7',1,'dbsetlbool(LOGINREC *login, int value, int which):&#160;dblib.c'],['../a00551.html#ga03e850369aca6fba074da5e9da4effd7',1,'dbsetlbool(LOGINREC *login, int value, int which):&#160;dblib.c']]],
  ['dbsetlcharset_261',['DBSETLCHARSET',['../a00545.html#ga316c0fd24b8dc1259ce9eb4d25016400',1,'sybdb.h']]],
  ['dbsetlencrypt_262',['DBSETLENCRYPT',['../a00545.html#gac51e3075197963557a8d2a37d82df921',1,'sybdb.h']]],
  ['dbsetlhost_263',['DBSETLHOST',['../a00544.html#gaef0e7a5fcf2d8c8f795b2b06ce4de8b1',1,'sybdb.h']]],
  ['dbsetllabeled_264',['DBSETLLABELED',['../a00551.html#gae52fc525116a3491c7e1092ad8257767',1,'sybdb.h']]],
  ['dbsetllong_265',['dbsetllong',['../a00551.html#gabdcccf4e0d093ff48c0e7048a4bfaf84',1,'dbsetllong(LOGINREC *login, long value, int which):&#160;dblib.c'],['../a00551.html#gabdcccf4e0d093ff48c0e7048a4bfaf84',1,'dbsetllong(LOGINREC *login, long value, int which):&#160;dblib.c']]],
  ['dbsetlname_266',['dbsetlname',['../a00551.html#gae1fc46447c4f8a9ff7f66607b8cd23b6',1,'dbsetlname(LOGINREC *login, const char *value, int which):&#160;dblib.c'],['../a00551.html#gae1fc46447c4f8a9ff7f66607b8cd23b6',1,'dbsetlname(LOGINREC *login, const char *value, int which):&#160;dblib.c']]],
  ['dbsetlnatlang_267',['dbsetlnatlang',['../a00545.html#ga30e0028e6208414c2245e5fcd6740d9d',1,'dbsetlnatlang():&#160;sybdb.h'],['../a00545.html#gadada0e76c811a6fb84ce6759bcf116b5',1,'DBSETLNATLANG():&#160;sybdb.h']]],
  ['dbsetlogintime_268',['dbsetlogintime',['../a00545.html#ga5f1281c07dde5a6d28e60ef62c501d1d',1,'dbsetlogintime(int seconds):&#160;dblib.c'],['../a00545.html#ga5f1281c07dde5a6d28e60ef62c501d1d',1,'dbsetlogintime(int seconds):&#160;dblib.c']]],
  ['dbsetlpacket_269',['DBSETLPACKET',['../a00545.html#gae7e59f9c3cc0ec5916c06977ff7d8565',1,'DBSETLPACKET():&#160;sybdb.h'],['../a00545.html#ga0d0acc4ce2243e48023e022b50e2ac45',1,'dbsetlpacket():&#160;sybdb.h']]],
  ['dbsetlpwd_270',['DBSETLPWD',['../a00544.html#ga61e04e8e2f0d7f1740d40634041f98eb',1,'sybdb.h']]],
  ['dbsetluser_271',['DBSETLUSER',['../a00544.html#gafbe7e48171d2f9b1d4f99e0bfdd98f5e',1,'sybdb.h']]],
  ['dbsetlversion_272',['DBSETLVERSION',['../a00551.html#ga7306859300823c120d807108a061c45a',1,'DBSETLVERSION():&#160;sybdb.h'],['../a00545.html#gaa22dce1ee0eb83059699c34c47d07c14',1,'dbsetlversion(LOGINREC *login, BYTE version):&#160;dblib.c'],['../a00545.html#gaa22dce1ee0eb83059699c34c47d07c14',1,'dbsetlversion(LOGINREC *login, BYTE version):&#160;dblib.c']]],
  ['dbsetmaxprocs_273',['dbsetmaxprocs',['../a00545.html#gaf2ca0e63f800b3839684c894ff651dd4',1,'dbsetmaxprocs(int maxprocs):&#160;dblib.c'],['../a00545.html#gaf2ca0e63f800b3839684c894ff651dd4',1,'dbsetmaxprocs(int maxprocs):&#160;dblib.c']]],
  ['dbsetnull_274',['dbsetnull',['../a00545.html#ga399512ec78c15ce3db79ea88ef3b1293',1,'dbsetnull(DBPROCESS *dbproc, int bindtype, int bindlen, BYTE *bindval):&#160;dblib.c'],['../a00545.html#ga399512ec78c15ce3db79ea88ef3b1293',1,'dbsetnull(DBPROCESS *dbprocess, int bindtype, int bindlen, BYTE *bindval):&#160;dblib.c']]],
  ['dbsetopt_275',['dbsetopt',['../a00545.html#ga9d660d278f3f58871b4086c0e175f4c6',1,'dbsetopt(DBPROCESS *dbproc, int option, const char *char_param, int int_param):&#160;dblib.c'],['../a00545.html#ga9d660d278f3f58871b4086c0e175f4c6',1,'dbsetopt(DBPROCESS *dbproc, int option, const char *char_param, int int_param):&#160;dblib.c']]],
  ['dbsetrow_276',['dbsetrow',['../a00545.html#gaeb3d621e4f6846bb228b0a596d8758c0',1,'dbsetrow(DBPROCESS *dbproc, DBINT row):&#160;dblib.c'],['../a00545.html#gaeb3d621e4f6846bb228b0a596d8758c0',1,'dbsetrow(DBPROCESS *dbprocess, DBINT row):&#160;dblib.c']]],
  ['dbsettime_277',['dbsettime',['../a00545.html#gada4b41f34542a87f0cd87e78e56d18bb',1,'dbsettime(int seconds):&#160;dblib.c'],['../a00545.html#gada4b41f34542a87f0cd87e78e56d18bb',1,'dbsettime(int seconds):&#160;dblib.c']]],
  ['dbsetuserdata_278',['dbsetuserdata',['../a00545.html#gabea9c70d02bf3e46bbb1d759915cb91e',1,'dbsetuserdata(DBPROCESS *dbproc, BYTE *ptr):&#160;dblib.c'],['../a00545.html#gabea9c70d02bf3e46bbb1d759915cb91e',1,'dbsetuserdata(DBPROCESS *dbproc, BYTE *ptr):&#160;dblib.c']]],
  ['dbsetversion_279',['dbsetversion',['../a00545.html#gab9aa181fb3081ffb314340cbd71e434d',1,'dbsetversion(DBINT version):&#160;dblib.c'],['../a00545.html#gab9aa181fb3081ffb314340cbd71e434d',1,'dbsetversion(DBINT version):&#160;dblib.c']]],
  ['dbspid_280',['dbspid',['../a00545.html#ga223a6d333f95e726b0b42ec19a076731',1,'dbspid(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga223a6d333f95e726b0b42ec19a076731',1,'dbspid(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbspr1row_281',['dbspr1row',['../a00545.html#gaf641c8e3d34607ca8b7ac2afed3e6d67',1,'dbspr1row(DBPROCESS *dbproc, char *buffer, DBINT buf_len):&#160;dblib.c'],['../a00545.html#gaf641c8e3d34607ca8b7ac2afed3e6d67',1,'dbspr1row(DBPROCESS *dbproc, char *buffer, DBINT buf_len):&#160;dblib.c']]],
  ['dbspr1rowlen_282',['dbspr1rowlen',['../a00545.html#ga308918c13a5b1644269c1654fbea96ac',1,'dbspr1rowlen(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga308918c13a5b1644269c1654fbea96ac',1,'dbspr1rowlen(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbsprhead_283',['dbsprhead',['../a00545.html#gaaa4839a9c88e5b90f33bd2407fcbc43e',1,'dbsprhead(DBPROCESS *dbproc, char *buffer, DBINT buf_len):&#160;dblib.c'],['../a00545.html#gaaa4839a9c88e5b90f33bd2407fcbc43e',1,'dbsprhead(DBPROCESS *dbproc, char *buffer, DBINT buf_len):&#160;dblib.c']]],
  ['dbsprline_284',['dbsprline',['../a00545.html#gacfaf9feb29c87cfb660886162f643152',1,'dbsprline(DBPROCESS *dbproc, char *buffer, DBINT buf_len, DBCHAR line_char):&#160;dblib.c'],['../a00545.html#gacfaf9feb29c87cfb660886162f643152',1,'dbsprline(DBPROCESS *dbproc, char *buffer, DBINT buf_len, DBCHAR line_char):&#160;dblib.c']]],
  ['dbsqlexec_285',['dbsqlexec',['../a00545.html#gaae889abeb145ec41f7361aa8f597fe46',1,'dbsqlexec(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gaae889abeb145ec41f7361aa8f597fe46',1,'dbsqlexec(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbsqlok_286',['dbsqlok',['../a00545.html#gae1f50a6a2c31fda57cb481922b06841e',1,'dbsqlok(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gae1f50a6a2c31fda57cb481922b06841e',1,'dbsqlok(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbsqlsend_287',['dbsqlsend',['../a00545.html#gac980139b9cea03cf93e373d425991481',1,'dbsqlsend(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#gac980139b9cea03cf93e373d425991481',1,'dbsqlsend(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbstrbuild_288',['dbstrbuild',['../a00545.html#gab5fe0cd5f24d4fd33670111035a4fbed',1,'dbstrbuild(DBPROCESS *dbproc, char *charbuf, int bufsize, char *text, char *formats,...):&#160;dblib.c'],['../a00545.html#gab5fe0cd5f24d4fd33670111035a4fbed',1,'dbstrbuild(DBPROCESS *dbproc, char *charbuf, int bufsize, char *text, char *formats,...):&#160;dblib.c']]],
  ['dbstrcpy_289',['dbstrcpy',['../a00545.html#gaf130b12e9e58b1bfd4a6685e33f5b3cd',1,'dbstrcpy(DBPROCESS *dbproc, int start, int numbytes, char *dest):&#160;dblib.c'],['../a00545.html#gaf130b12e9e58b1bfd4a6685e33f5b3cd',1,'dbstrcpy(DBPROCESS *dbproc, int start, int numbytes, char *dest):&#160;dblib.c']]],
  ['dbstring_290',['dbstring',['../a01324.html',1,'']]],
  ['dbstrlen_291',['dbstrlen',['../a00545.html#ga13caa07ec45cd6f64e9197d29e3cfe5e',1,'dbstrlen(DBPROCESS *dbproc):&#160;dblib.c'],['../a00545.html#ga13caa07ec45cd6f64e9197d29e3cfe5e',1,'dbstrlen(DBPROCESS *dbproc):&#160;dblib.c']]],
  ['dbtablecolinfo_292',['dbtablecolinfo',['../a00545.html#ga9804fc70ae6ed35c92cd75d410dad570',1,'dbtablecolinfo(DBPROCESS *dbproc, DBINT column, DBCOL *pdbcol):&#160;dblib.c'],['../a00545.html#ga9804fc70ae6ed35c92cd75d410dad570',1,'dbtablecolinfo(DBPROCESS *dbproc, DBINT column, DBCOL *pdbcol):&#160;dblib.c']]],
  ['dbtds_293',['DBTDS',['../a00545.html#ga1644cf55d37435711df65c12a3f7b785',1,'DBTDS():&#160;sybdb.h'],['../a00551.html#ga8d765d810a40dfa01b39995a8e7406f0',1,'dbtds(DBPROCESS *dbproc):&#160;dblib.c'],['../a00551.html#ga8d765d810a40dfa01b39995a8e7406f0',1,'dbtds(DBPROCESS *dbprocess):&#160;dblib.c']]],
  ['dbtds_5funknown_294',['DBTDS_UNKNOWN',['../a00503.html#a4e19c79341755a7c6666197d381e1ac6',1,'sybdb.h']]],
  ['dbtxptr_295',['dbtxptr',['../a00545.html#ga57e4098b153a030f0be02bcd98e08ba2',1,'dbtxptr(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#ga57e4098b153a030f0be02bcd98e08ba2',1,'dbtxptr(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbtxtimestamp_296',['dbtxtimestamp',['../a00545.html#gac3f11142ec7ff25b1f8972af10fe9454',1,'dbtxtimestamp(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#gac3f11142ec7ff25b1f8972af10fe9454',1,'dbtxtimestamp(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbtypeinfo_297',['dbtypeinfo',['../a01320.html',1,'']]],
  ['dbuse_298',['dbuse',['../a00545.html#ga66ea891910f0a357cc78107d6ab7d962',1,'dbuse(DBPROCESS *dbproc, const char *name):&#160;dblib.c'],['../a00545.html#ga66ea891910f0a357cc78107d6ab7d962',1,'dbuse(DBPROCESS *dbproc, const char *name):&#160;dblib.c']]],
  ['dbvarybin_299',['DBVARYBIN',['../a01292.html',1,'']]],
  ['dbvarychar_300',['DBVARYCHAR',['../a01288.html',1,'']]],
  ['dbvarylen_301',['dbvarylen',['../a00545.html#ga57c856964a9a0b4cc43f5192647c51e7',1,'dbvarylen(DBPROCESS *dbproc, int column):&#160;dblib.c'],['../a00545.html#ga57c856964a9a0b4cc43f5192647c51e7',1,'dbvarylen(DBPROCESS *dbproc, int column):&#160;dblib.c']]],
  ['dbversion_302',['dbversion',['../a00545.html#ga666726c86108342b1c1f27eecf68e13c',1,'dbversion():&#160;dblib.c'],['../a00545.html#ga666726c86108342b1c1f27eecf68e13c',1,'dbversion(void):&#160;dblib.c']]],
  ['dbversion_5funknown_303',['DBVERSION_UNKNOWN',['../a00503.html#adbc038c5d57c0ab4c1c9e081a664dc0f',1,'sybdb.h']]],
  ['dbwillconvert_304',['dbwillconvert',['../a00545.html#gaaf8349999c16b3c36caf5947747a2915',1,'dbwillconvert(int srctype, int desttype):&#160;dblib.c'],['../a00545.html#gaaf8349999c16b3c36caf5947747a2915',1,'dbwillconvert(int srctype, int desttype):&#160;dblib.c']]],
  ['dbwritetext_305',['dbwritetext',['../a00545.html#ga548153eb2eae76c48aa9d4b72258dc1c',1,'dbwritetext(DBPROCESS *dbproc, char *objname, DBBINARY *textptr, DBTINYINT textptrlen, DBBINARY *timestamp, DBBOOL log, DBINT size, BYTE *text):&#160;dblib.c'],['../a00545.html#ga548153eb2eae76c48aa9d4b72258dc1c',1,'dbwritetext(DBPROCESS *dbproc, char *objname, DBBINARY *textptr, DBTINYINT textptrlen, DBBINARY *timestamp, DBBOOL log, DBINT size, BYTE *text):&#160;dblib.c']]],
  ['decimicrosecond_306',['decimicrosecond',['../a01112.html#a838e73fd12eec9e3b5368316198f4762',1,'tdsdaterec']]],
  ['default_5ferr_5fhandler_307',['default_err_handler',['../a00551.html#gaccbc6d98d9528c48cf0254d809ca73ff',1,'dblib.c']]],
  ['defer_5fclose_308',['defer_close',['../a01188.html#a411e76370c635dfabe9b5941cdd3180f',1,'tds_cursor::defer_close()'],['../a01196.html#a744986c76b9b09f29325a1e0664b0e9a',1,'tds_dynamic::defer_close()']]],
  ['des_5fkey_309',['des_key',['../a01248.html',1,'']]],
  ['determine_5fadjusted_5fsize_310',['determine_adjusted_size',['../a00562.html#ga87209537d51f069fee02bc224da492cb',1,'determine_adjusted_size(const TDSICONV *char_conv, int size):&#160;token.c'],['../a00562.html#ga87209537d51f069fee02bc224da492cb',1,'determine_adjusted_size(const TDSICONV *char_conv, int size):&#160;token.c']]],
  ['dlist_5flist_5ftype_311',['DLIST_LIST_TYPE',['../a01256.html',1,'']]],
  ['dlist_5fring_312',['dlist_ring',['../a01252.html',1,'']]],
  ['dsn_313',['dsn',['../a00664.html#acd76726add649629f26f1f1754fe48cf',1,'DSNINFO']]],
  ['dsninfo_314',['DSNINFO',['../a00664.html',1,'']]],
  ['dstr_315',['DSTR',['../a00563.html#gafddddf5bd7ad223cadee3d3bdc899954',1,'string.h']]],
  ['dstr_5finitializer_316',['DSTR_INITIALIZER',['../a00563.html#ga581a03a4de6c926c57b4a75a11214df4',1,'string.h']]],
  ['dynamic_20string_20functions_317',['Dynamic string functions',['../a00563.html',1,'']]],
  ['dyns_318',['dyns',['../a01220.html#a7dc98cfe507c626073b6e76985a06a8a',1,'tds_connection']]]
];
